@@ -1,6 +1,7 @@
 from ipywidgets import Widget
-from traitlets import Unicode, List, Bool, Dict, Any, validate
-from ._type import type_detect
+from six import iteritems
+from traitlets import Unicode, List, Bool, Int, Dict, Any, validate
+from .data import type_detect
 from ._layout import validate_view, validate_columns, validate_rowpivots, validate_columnpivots, validate_aggregates, validate_sort
 from ._schema import validate_schema
 
@@ -8,14 +9,12 @@ from ._schema import validate_schema
 class PerspectiveWidget(Widget):
     _model_name = Unicode('PerspectiveModel').tag(sync=True)
     _model_module = Unicode('@jpmorganchase/perspective-jupyterlab').tag(sync=True)
-    _model_module_version = Unicode('0.1.18').tag(sync=True)
+    _model_module_version = Unicode('0.2.7').tag(sync=True)
     _view_name = Unicode('PerspectiveView').tag(sync=True)
     _view_module = Unicode('@jpmorganchase/perspective-jupyterlab').tag(sync=True)
-    _view_module_version = Unicode('0.1.18').tag(sync=True)
+    _view_module_version = Unicode('0.2.7').tag(sync=True)
 
     _data = List(default_value=[]).tag(sync=True)
-    # _data_tick = List(default_value=[]).tag(sync=True)
-
     _dat_orig = Any()
 
     datasrc = Unicode(default_value='static').tag(sync=True)
@@ -26,6 +25,8 @@ class PerspectiveWidget(Widget):
     columnpivots = List(trait=Unicode(), default_value=[]).tag(sync=True)
     aggregates = Dict(trait=Unicode(), default_value={}).tag(sync=True)
     sort = List(default_value=[]).tag(sync=True)
+    index = Unicode(default_value='').tag(sync=True)
+    limit = Int(default_value=-1).tag(sync=True)
 
     settings = Bool(True).tag(sync=True)
     dark = Bool(False).tag(sync=True)
@@ -34,25 +35,21 @@ class PerspectiveWidget(Widget):
         self.send({'type': 'delete'})
 
     def update(self, data):
-        typ, dat_orig, data_new = type_detect(data)
-        self.send({'type': 'update', 'data': data_new})
+        dat_obj = type_detect(data)
+        self.send({'type': 'update', 'data': dat_obj.data})
 
     def load(self, value):
-        typ, dat_orig, dat = type_detect(value)
+        data_object = type_detect(value)
 
-        if typ == 'url':
-            # unconvertable, must be http/ws/sio/comm
-            self._dat_orig = dat_orig
-            dat = []
-            dat_orig = ''
-        else:
-            self._dat_orig = dat_orig
-
-        if len(dat_orig) and typ:
-            s = validate_schema(dat_orig, typ)
+        # len in case dataframe
+        if len(data_object.data) and data_object.type:
+            s = validate_schema(data_object.schema)
             self.schema = s
-            if not self.columns:
+
+            if not self.columns and 'columns' not in data_object.kwargs:
                 columns = list(map(lambda x: str(x), s.keys()))
+
+                # reasonable default, pivot by default in non-grid view
                 if not self.rowpivots and self.view != 'hypergrid':
                     if 'index' in columns:
                         self.rowpivots = ['index']
@@ -60,10 +57,18 @@ class PerspectiveWidget(Widget):
                             columns.remove('index')
                 self.columns = columns
 
+            elif 'columns' in data_object.kwargs:
+                columns = list(map(lambda x: str(x), data_object.kwargs.pop('columns')))
+                self.columns = columns
+
         else:
             self.schema = {}
 
-        self._data = dat
+        for k, v in iteritems(data_object.kwargs):
+            setattr(self, k, v)
+
+        # set data last
+        self._data = data_object.data
 
     @validate('datasrc')
     def _validate_datasrc(self, proposal):
@@ -108,13 +113,15 @@ class PerspectiveWidget(Widget):
     def __del__(self):
         self.send({'type': 'delete'})
 
-    def __init__(self, data, view='hypergrid', schema=None, columns=None, rowpivots=None, columnpivots=None, aggregates=None, sort=None, settings=True, dark=False, *args, **kwargs):
+    def __init__(self, data, view='hypergrid', schema=None, columns=None, rowpivots=None, columnpivots=None, aggregates=None, sort=None, index='', limit=-1, settings=True, dark=False, *args, **kwargs):
         super(PerspectiveWidget, self).__init__(**kwargs)
         self._helper = None
         self.datasrc = 'static'
         self.view = validate_view(view)
         self.schema = schema or {}
         self.sort = validate_sort(sort) or []
+        self.index = index
+        self.limit = limit
         self.settings = settings
         self.dark = dark
 
